@@ -21,7 +21,7 @@ if __name__ == "__main__":
     )
     parser.add_argument(
         "--cloud_convert",
-        default=False,
+        default=True,
         type=bool,
         help="Do you need to convert 3D images to point clouds?",
     )
@@ -46,19 +46,22 @@ if __name__ == "__main__":
     )
     parser.add_argument(
         "--tif_dataset_path",
-        default="./dataset_tif/",
+        default="/home/mvries/Documents/CellShape/"
+        "UploadData/Dataset/TestConvert/TestTiff/",
         type=str,
         help="Please provide the path to the " "dataset of 3D tif images",
     )
     parser.add_argument(
         "--mesh_dataset_path",
-        default="./dataset_mesh/",
+        default="/home/mvries/Documents/CellShape/"
+        "UploadData/Dataset/TestConvert/TestMesh/",
         type=str,
         help="Please provide the path to the " "dataset of 3D meshes.",
     )
     parser.add_argument(
         "--cloud_dataset_path",
-        default="/home/mvries/Documents/CellShape/DatasetForTesting/",
+        default="/home/mvries/Documents/CellShape/"
+        "UploadData/Dataset/TestConvert/TestPointCloud/",
         type=str,
         help="Please provide the path to the " "dataset of the point clouds.",
     )
@@ -73,7 +76,8 @@ if __name__ == "__main__":
     )
     parser.add_argument(
         "--dataframe_path",
-        default="./dataframe/",
+        default="/home/mvries/Documents/CellShape/UploadData/"
+        "Dataset/all_data_removedwrong_ori_removedTwo.csv",
         type=str,
         help="Please provide the path to the dataframe "
         "containing information on the dataset.",
@@ -143,6 +147,30 @@ if __name__ == "__main__":
         type=int,
         help="Please provide the batch size.",
     )
+    parser.add_argument(
+        "--update_interval",
+        default=1,
+        type=int,
+        help="Please provide the update interval.",
+    )
+    parser.add_argument(
+        "--gamma",
+        default=1,
+        type=int,
+        help="Please provide the value for gamma.",
+    )
+    parser.add_argument(
+        "--alpha",
+        default=1.0,
+        type=float,
+        help="Please provide the value for alpha.",
+    )
+    parser.add_argument(
+        "--divergence_tolerance",
+        default=0.01,
+        type=float,
+        help="Please provide the divergence tolerance.",
+    )
     parser.add_argument(
         "--proximal",
         default=0,
@@ -152,9 +180,9 @@ if __name__ == "__main__":
     )
     parser.add_argument(
         "--pretrained_path",
-        default="/run/user/1128299809/gvfs/smb-share:server=rds.icr.ac.uk,"
-        "share=data/DBI/DUDBI/DYNCESYS/mvries/ResultsAlma/TearingNetNew/"
-        "nets/dgcnn_foldingnet_128_008.pt",
+        default="/home/mvries/Documents/CellShape/"
+        "UploadData/Models/cloud_autoencoder/"
+        "dgcnn_foldingnet_128_001.pt",
         type=str,
         help="Please provide the path to a pretrained autoencoder.",
     )
@@ -167,12 +195,22 @@ if __name__ == "__main__":
         # Do we need to convert the data?
         # Yes:
         if args.cloud_convert:
-            cshelper.tif_to_pc_directory(
-                tif_directory=args.dataset_tif,
-                save_mesh=args.dataset_mesh,
-                save_points=args.dataset_cloud,
-                num_points=args.num_points,
-            )
+            if args.dataset_type == "SingleCell":
+                print("No need to convert as these are given.")
+            else:
+                print(
+                    f"Converting tif files from {args.tif_dataset_path}, \n"
+                    f"and saving mesh object files to"
+                    f" {args.mesh_dataset_path} \n"
+                    f"and point cloud files to {args.cloud_dataset_path}"
+                )
+                cshelper.tif_to_pc_directory(
+                    tif_directory=args.tif_dataset_path,
+                    save_mesh=args.mesh_dataset_path,
+                    save_points=args.cloud_dataset_path,
+                    num_points=args.num_points,
+                )
+
         # If no, continue.
         # Do we want to pretrain the autoencoder FIRST?
         # Yes
@@ -194,7 +232,6 @@ if __name__ == "__main__":
                     name_ae,
                 ) = cscloud.train_autoencoder(args)
 
-                # todo: logging.close()
                 model = cscluster.DeepEmbeddedClustering(
                     autoencoder=autoencoder, num_clusters=args.num_clusters
                 )
@@ -227,7 +264,7 @@ if __name__ == "__main__":
 
                 optimizer = torch.optim.Adam(
                     autoencoder.parameters(),
-                    lr=args.learning_rate_cluster * 16 / args.batch_size,
+                    lr=args.learning_rate_clustering * 16 / args.batch_size,
                     betas=(0.9, 0.999),
                     weight_decay=1e-6,
                 )
@@ -355,16 +392,16 @@ if __name__ == "__main__":
             if file_not_found:
                 logging.info(
                     f"The autoencoder model at {args.pretrained_path}"
-                    f" doesn't exist."
-                    f"if you knew this already, then don't worry. "
-                    f"If not, then check the path and try again"
+                    f" doesn't exist. "
+                    f"If you knew this already, then don't worry. "
+                    f"If not, then check the path and try again."
                 )
                 logging.info("Training from scratch")
                 print(
                     f"The autoencoder model at "
                     f"{args.pretrained_path} doesn't exist."
                     f"if you knew this already, then don't worry. "
-                    f"If not, then check the path and try again"
+                    f"If not, then check the path and try again."
                 )
                 print("Training from scratch")
 
@@ -399,129 +436,3 @@ if __name__ == "__main__":
                 divergence_tolerance=args.divergence_tolerance,
                 logging_info=logging_info,
             )
-
-    # ############################################################
-    # # Cache some errors
-    # if args.train_type == "pretrain" and not args.pretrain:
-    #     print("Nothing to do :(")
-    #     exit()
-    #
-    # if args.cloud_convert and not (args.model_type == "cloud"):
-    #     print(
-    #         "Not converting to point clouds "
-    #         "as you are not using the cloud models."
-    #     )
-    #
-    # if args.model_type == "cloud":
-    #
-    #     autoencoder = cscloud.CloudAutoEncoder(
-    #         num_features=args.num_features,
-    #         k=args.k,
-    #         encoder_type=args.encoder_type,
-    #         decoder_type=args.decoder_type,
-    #     )
-    #
-    #     dataset = cscloud.PointCloudDataset(args.input_dir)
-    #
-    #     dataloader = DataLoader(dataset,
-    #     batch_size=args.batch_size, shuffle=True)
-    #
-    #     reconstruction_criterion = ChamferLoss()
-    #
-    #     optimizer = torch.optim.Adam(
-    #         autoencoder.parameters(),
-    #         lr=args.learning_rate_autoencoder * 16 / args.batch_size,
-    #         betas=(0.9, 0.999),
-    #         weight_decay=1e-6,
-    #     )
-    #
-    #     (
-    #         autoencoder,
-    #         name_logging,
-    #         name_model,
-    #         name_writer,
-    #         name,
-    #     ) = cscloud.train(
-    #         autoencoder,
-    #         dataloader,
-    #         args.num_epochs_autoencoder,
-    #         reconstruction_criterion,
-    #         optimizer,
-    #         args.output_dir,
-    #     )
-    #
-    # else:
-    #     autoencoder = csvoxel.VoxelAutoEncoder(
-    #         num_features=args.num_features,
-    #         encoder_type=args.encoder_type,
-    #         decoder_type=args.decoder_type,
-    #     )
-    #
-    #     dataset = csvoxel.VoxelDataset(args.input_dir)
-    #
-    #     dataloader = DataLoader(dataset,
-    #     batch_size=args.batch_size, shuffle=True)
-    #
-    #     reconstruction_criterion = FocalTverskyLoss()
-    #
-    #     optimizer = torch.optim.Adam(
-    #         autoencoder.parameters(),
-    #         lr=args.learning_rate_autoencoder * 16 / args.batch_size,
-    #         betas=(0.9, 0.999),
-    #         weight_decay=1e-6,
-    #     )
-    #
-    #     (
-    #         autoencoder,
-    #         name_logging,
-    #         name_model,
-    #         name_writer,
-    #         name,
-    #     ) = csvoxel.train(
-    #         autoencoder,
-    #         dataloader,
-    #         args.num_epochs_autoencoder,
-    #         reconstruction_criterion,
-    #         optimizer,
-    #         args.output_dir,
-    #     )
-    #
-    # if args.train_type == "pretrain" and args.pretrain:
-    #     print()
-    #
-    # model = cscluster.DeepEmbeddedClustering(
-    #     autoencoder=autoencoder, num_clusters=args.num_clusters
-    # )
-    #
-    # dataloader = DataLoader(
-    #     dataset, batch_size=args.batch_size, shuffle=False
-    # )  # it is very important that shuffle=False here!
-    # dataloader_inf = DataLoader(
-    #     dataset, batch_size=1, shuffle=False
-    # )  # it is very important that batch_size=1 and shuffle=False here!
-    #
-    # optimizer = torch.optim.Adam(
-    #     model.parameters(),
-    #     lr=args.learning_rate_clustering * 16 / args.batch_size,
-    #     betas=(0.9, 0.999),
-    #     weight_decay=1e-6,
-    # )
-    #
-    # reconstruction_criterion = ChamferLoss()
-    # cluster_criterion = torch.nn.KLDivLoss(reduction="sum")
-    #
-    # cscluster.train(
-    #     model=model,
-    #     dataloader=dataloader,
-    #     dataloader_inf=dataloader_inf,
-    #     num_epochs=args.num_epochs_clustering,
-    #     optimizer=optimizer,
-    #     reconstruction_criterion=reconstruction_criterion,
-    #     cluster_criterion=cluster_criterion,
-    #     update_interval=args.update_interval,
-    #     gamma=args.gamma,
-    #     divergence_tolerance=args.divergence_tolerance,
-    #     logging_info=logging_info,
-    # )
-    #
-    # cellshape_train(args)
